more verbosity in trace diffs
Change-Id: I1e3f6c8ee126ca4470f0846aabab19d18397dd64
[ROCm/roctracer commit: 0502f196d9]
Этот коммит содержится в:
коммит произвёл
Evgeny
родитель
9dce4ee5f3
Коммит
2e189165df
@@ -26,16 +26,21 @@ import argparse
|
||||
|
||||
events_count = {}
|
||||
events_order = {}
|
||||
events_order_r = {}
|
||||
trace2info = {}
|
||||
trace2info_filename = 'test/tests_trace_cmp_levels.txt'
|
||||
|
||||
# Parses trace comparison config file and stores the info in a dictionary
|
||||
def parse_trace_levels(trace_config_filename):
|
||||
def parse_trace_levels(trace_config_filename, check_trace_flag):
|
||||
status = 0
|
||||
f = open(trace_config_filename)
|
||||
trace2info = {}
|
||||
for line in f:
|
||||
if re.match('^# dummy',line):
|
||||
return trace2info
|
||||
if check_trace_flag == 0:
|
||||
return (trace2info, status)
|
||||
if (check_trace_flag == None) and re.match('^# dummy',line):
|
||||
return (trace2info, status)
|
||||
status = 1
|
||||
lis = line.split(' ')
|
||||
trace_name = lis[0]
|
||||
comp_level = lis[1]
|
||||
@@ -70,16 +75,81 @@ def parse_trace_levels(trace_config_filename):
|
||||
|
||||
trace2info[trace_name] = (comp_level,no_events_cnt,events2ignore,events2chkcnt,events2chkord,events2ch)
|
||||
|
||||
return trace2info
|
||||
return (trace2info, status)
|
||||
|
||||
# check trace againt golden reference and returns 0 for pass, 1 for fail
|
||||
def check_trace_status(tracename, verbose):
|
||||
trace2info = parse_trace_levels(trace2info_filename)
|
||||
# diff multi lines strings to show events differences
|
||||
def diff_strings(cnt_r, cnt, metric):
|
||||
global events_order_r
|
||||
global events_order
|
||||
|
||||
print ("\nDiffs (if any):\n")
|
||||
if metric == 'cnt':
|
||||
evt_ptrn = re.compile(r'(\w+).*$')
|
||||
#cnt_ptrn = re.compile(r'(\w+): count (\d+)$')
|
||||
for evt in cnt_r.split('\n'):
|
||||
mevt_ptrn = evt_ptrn.match(evt)
|
||||
#mcnt_ptrn = cnt_ptrn.match(evt)
|
||||
if mevt_ptrn:
|
||||
if not re.search(mevt_ptrn.group(1), cnt):
|
||||
print ('+ ' + evt)
|
||||
elif not re.search(evt, cnt):
|
||||
print ('>D< ' + evt)
|
||||
|
||||
for evt in cnt.split('\n'):
|
||||
mevt_ptrn = evt_ptrn.match(evt)
|
||||
#mcnt_ptrn = cnt_ptrn.match(evt)
|
||||
if mevt_ptrn:
|
||||
if not re.search(mevt_ptrn.group(1), cnt_r):
|
||||
print ('- ' + evt)
|
||||
if metric == 'or':
|
||||
cnt_tid_r = 0
|
||||
for tid_r in sorted (events_order_r.keys()):
|
||||
if len(events_order) == 0:
|
||||
print ("+ " + str(events_order_r[tid_r]) + "\n\n")
|
||||
continue
|
||||
cnt_tid = 0
|
||||
for tid in sorted (events_order.keys()):
|
||||
if cnt_tid == cnt_tid_r:
|
||||
if events_order_r[tid_r] != events_order[tid]:
|
||||
#print (">D< " + str(events_order_r[tid_r]) + "\n")
|
||||
#print (">D< " + str(events_order[tid]) + "\n\n")
|
||||
diff_cnt_r = 0
|
||||
found_diff_evt = 0
|
||||
for evt in events_order_r[tid_r]:
|
||||
diff_cnt = 0
|
||||
for evt2 in events_order[tid]:
|
||||
if diff_cnt == diff_cnt_r:
|
||||
if evt != evt2:
|
||||
print (">I< Difference starts at index: " + str(diff_cnt_r) + ", tid_r " + str(tid_r) + ", tid " + str(tid) + ", with evts " + evt + " and " + evt2 + "\n")
|
||||
found_diff_evt = 1
|
||||
break
|
||||
diff_cnt += 1
|
||||
diff_cnt_r += 1
|
||||
if found_diff_evt: break
|
||||
if len(events_order_r[tid_r]) != len(events_order[tid]) and found_diff_evt == 0:
|
||||
print (">I< Difference starts at index: " + str(min(len(events_order_r[tid_r]), len(events_order[tid]))) + ", with missing evts\n")
|
||||
break
|
||||
cnt_tid += 1
|
||||
cnt_tid_r += 1
|
||||
if len(events_order_r) == 0:
|
||||
for tid in sorted (events_order.keys()):
|
||||
print ("- " + str(events_order[tid]) + "\n")
|
||||
|
||||
# check trace againt golden reference and returns 0 for pass, 1 for fail
|
||||
def check_trace_status(tracename, verbose, check_trace_flag):
|
||||
global events_order_r
|
||||
global events_order
|
||||
|
||||
(trace2info, status) = parse_trace_levels(trace2info_filename, check_trace_flag)
|
||||
|
||||
if len(trace2info) == 0:
|
||||
if verbose:
|
||||
if status == 1:
|
||||
print ("Error: no trace comparison info found in config file " + trace2info_filename + "\n")
|
||||
print('FAILED!')
|
||||
return 1
|
||||
if status == 0:
|
||||
print('PASSED!')
|
||||
return 0
|
||||
return 0
|
||||
|
||||
trace = 'test/' + tracename + '.txt'
|
||||
rtrace = tracename + '.txt'
|
||||
@@ -92,7 +162,8 @@ def check_trace_status(tracename, verbose):
|
||||
events2chkord = events2chkord.rstrip('\n')
|
||||
events2ch = events2ch.rstrip('\n')
|
||||
else:
|
||||
print('Trace ' + os.path.basename(tracename) + ' not found in ' + trace2info_filename + ', defaulting to level 0 i.e. no trace comparison')
|
||||
print('Trace ' + os.path.basename(tracename) + ' not found in ' + trace2info_filename)
|
||||
print('FAILED!')
|
||||
return 1
|
||||
|
||||
if no_events_cnt == '':
|
||||
@@ -105,34 +176,47 @@ def check_trace_status(tracename, verbose):
|
||||
events2chkord = ''
|
||||
|
||||
if trace_level == '--check-none':
|
||||
if verbose:
|
||||
print('PASSED!')
|
||||
print('PASSED!')
|
||||
return 0
|
||||
|
||||
if trace_level == '--check-diff':
|
||||
if filecmp.cmp(trace,rtrace):
|
||||
if verbose:
|
||||
print('PASSED!')
|
||||
print('PASSED!')
|
||||
return 0
|
||||
else:
|
||||
print('FAILED!')
|
||||
os.system('/usr/bin/diff --brief ' + trace + ' ' + rtrace)
|
||||
return 1
|
||||
|
||||
metric = ''
|
||||
if trace_level == '--check-count' or trace_level == '--check-events':
|
||||
metric = 'cnt'
|
||||
if trace_level == '--check-order':
|
||||
metric = 'or'
|
||||
|
||||
cnt_r = gen_events_info(rtrace,trace_level,no_events_cnt,events2ignore,events2chkcnt,events2chkord,verbose)
|
||||
events_order_r = {}
|
||||
for tid in sorted (events_order.keys()) :
|
||||
events_order_r[tid] = events_order[tid]
|
||||
cnt = gen_events_info(trace,trace_level,no_events_cnt,events2ignore,events2chkcnt,events2chkord,verbose)
|
||||
if verbose:
|
||||
print '\n' + rtrace + ':\n'
|
||||
print cnt_r
|
||||
print '\n' + trace + ':\n'
|
||||
print cnt
|
||||
diff_strings(cnt_r, cnt, metric)
|
||||
|
||||
if cnt_r == cnt:
|
||||
if verbose:
|
||||
print('PASSED!')
|
||||
print('PASSED!')
|
||||
return 0
|
||||
else:
|
||||
if verbose:
|
||||
print('FAILED!')
|
||||
print('FAILED!')
|
||||
return 1
|
||||
|
||||
# Parses roctracer trace file for regression purpose
|
||||
# and generates events count per event (when cnt is on) or events order per tid (when order is on)
|
||||
def gen_events_info(tracefile, trace_level, no_events_cnt, events2ignore, events2chkcnt, events2chkord, verbose):
|
||||
global events_order
|
||||
metric = ''
|
||||
if trace_level == '--check-count' or trace_level == '--check-events':
|
||||
metric = 'cnt'
|
||||
@@ -150,18 +234,20 @@ def gen_events_info(tracefile, trace_level, no_events_cnt, events2ignore, events
|
||||
test_act_pattern = re.compile(r'\s*(\w+)\s+.*_id\((\d+)\)$')
|
||||
#' hipSetDevice correlation_id(1) time_ns(1548622357525055:1548622357542015) process_id(126283) thread_id(126283)'
|
||||
#' hcCommandKernel correlation_id(6) time_ns(1548622661443020:1548622662666935) device_id(0) queue_id(0)'
|
||||
test_api_cb_pattern = re.compile(r'<(\w+)\s+.*tid\((\d+)\)>')
|
||||
test_api_cb_pattern = re.compile(r'.*<(\w+)\s+.*tid\((\d+)\)>')
|
||||
# <hsaKmtGetVersion id(2) correlation_id(0) on-enter pid(26224) tid(26224)>
|
||||
# below is roctx pattern
|
||||
# <hipLaunchKernel pid(123) tid(123)>
|
||||
tool_record = re.compile(r'\d+:\d+\s+\d+:(\d+)\s+(\w+)')
|
||||
# tool_api_record
|
||||
# tool_api_record
|
||||
# 1822810364769411:1822810364771941 116477:116477 hsa_agent_get_info(<agent 0x8990e0>, 17, 0x7ffeac015fec) = 0
|
||||
# tool_gpu_act_record
|
||||
# tool_gpu_act_record
|
||||
# 3632773658039902:3632773658046462 0:0 hcCommandMarker:273
|
||||
|
||||
with open(tracefile) as f:
|
||||
for line in f:
|
||||
if re.search("before", line) or re.search("after",line):#roctx before/after not real events
|
||||
continue
|
||||
line=line.rstrip('\n')
|
||||
event = ''
|
||||
test_act_pattern_match = test_act_pattern.match(line)
|
||||
@@ -206,17 +292,17 @@ def gen_events_info(tracefile, trace_level, no_events_cnt, events2ignore, events
|
||||
if metric == 'or':
|
||||
for tid in sorted (events_order.keys()) :
|
||||
res = res + str(events_order[tid])
|
||||
if verbose:
|
||||
print(res)
|
||||
return res
|
||||
|
||||
parser = argparse.ArgumentParser(description='check_trace.py: check a trace aainst golden ref. Returns 0 for success, 1 for failure')
|
||||
requiredNamed = parser.add_argument_group('Required arguments')
|
||||
requiredNamed.add_argument('-in', metavar='file', help='Name of trace to be checked', required=True)
|
||||
requiredNamed.add_argument('-v', action='store_true', help='debug info', required=False)
|
||||
requiredNamed.add_argument('-ck', metavar='N', type=int, help='check trace 0|1', required=False)
|
||||
|
||||
args = vars(parser.parse_args())
|
||||
|
||||
if __name__ == '__main__':
|
||||
sys.exit(check_trace_status(args['in'],args['v']))
|
||||
sys.exit(check_trace_status(args['in'],args['v'],args['ck']))
|
||||
|
||||
|
||||
|
||||
@@ -36,9 +36,15 @@ using namespace std;
|
||||
// roctracer extension API
|
||||
#include <roctracer_ext.h>
|
||||
|
||||
const size_t msg_size = 512;
|
||||
char* msg_buf = NULL;
|
||||
char* message = NULL;
|
||||
#ifdef __cplusplus
|
||||
static thread_local const size_t msg_size = 512;
|
||||
static thread_local char* msg_buf = NULL;
|
||||
static thread_local char* message = NULL;
|
||||
#else
|
||||
static const size_t msg_size = 512;
|
||||
static char* msg_buf = NULL;
|
||||
static char* message = NULL;
|
||||
#endif
|
||||
void SPRINT(const char* fmt, ...) {
|
||||
if (msg_buf == NULL) {
|
||||
msg_buf = (char*) calloc(msg_size, 1);
|
||||
@@ -259,24 +265,24 @@ void api_callback(
|
||||
|
||||
if (domain == ACTIVITY_DOMAIN_ROCTX) {
|
||||
const roctx_api_data_t* data = (const roctx_api_data_t*)(callback_data);
|
||||
fprintf(stdout, "<rocTX \"%s\">\n", data->args.message);
|
||||
fprintf(stdout, "rocTX <\"%s pid(%d) tid(%d)\">\n", data->args.message, GetPid(), GetTid());
|
||||
return;
|
||||
}
|
||||
if (domain == ACTIVITY_DOMAIN_KFD_API) {
|
||||
const kfd_api_data_t* data = (const kfd_api_data_t*)(callback_data);
|
||||
fprintf(stdout, "<%s id(%u)\tcorrelation_id(%lu) %s>\n",
|
||||
fprintf(stdout, "<%s id(%u)\tcorrelation_id(%lu) %s pid(%d) tid(%d)>\n",
|
||||
roctracer_op_string(ACTIVITY_DOMAIN_KFD_API, cid, 0),
|
||||
cid,
|
||||
data->correlation_id,
|
||||
(data->phase == ACTIVITY_API_PHASE_ENTER) ? "on-enter" : "on-exit");
|
||||
(data->phase == ACTIVITY_API_PHASE_ENTER) ? "on-enter" : "on-exit", GetPid(), GetTid());
|
||||
return;
|
||||
}
|
||||
const hip_api_data_t* data = (const hip_api_data_t*)(callback_data);
|
||||
SPRINT("<%s id(%u)\tcorrelation_id(%lu) %s> ",
|
||||
SPRINT("<%s id(%u)\tcorrelation_id(%lu) %s pid(%d) tid(%d)> ",
|
||||
roctracer_op_string(ACTIVITY_DOMAIN_HIP_API, cid, 0),
|
||||
cid,
|
||||
data->correlation_id,
|
||||
(data->phase == ACTIVITY_API_PHASE_ENTER) ? "on-enter" : "on-exit");
|
||||
(data->phase == ACTIVITY_API_PHASE_ENTER) ? "on-enter" : "on-exit", GetPid(), GetTid());
|
||||
if (data->phase == ACTIVITY_API_PHASE_ENTER) {
|
||||
switch (cid) {
|
||||
case HIP_API_ID_hipMemcpy:
|
||||
|
||||
@@ -1,501 +1,502 @@
|
||||
+ LD_PRELOAD=libkfdwrapper64.so ./test/MatrixTranspose_ctest
|
||||
# INIT #############################
|
||||
# START (99) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (98) #############################
|
||||
PASSED!
|
||||
# START (97) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (96) #############################
|
||||
PASSED!
|
||||
# START (95) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (94) #############################
|
||||
PASSED!
|
||||
# START (93) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (92) #############################
|
||||
PASSED!
|
||||
# START (91) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (90) #############################
|
||||
PASSED!
|
||||
# START (89) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (88) #############################
|
||||
PASSED!
|
||||
# START (87) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (86) #############################
|
||||
PASSED!
|
||||
# START (85) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (84) #############################
|
||||
PASSED!
|
||||
# START (83) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (82) #############################
|
||||
PASSED!
|
||||
# START (81) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (80) #############################
|
||||
PASSED!
|
||||
# START (79) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (78) #############################
|
||||
PASSED!
|
||||
# START (77) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (76) #############################
|
||||
PASSED!
|
||||
# START (75) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (74) #############################
|
||||
PASSED!
|
||||
# START (73) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (72) #############################
|
||||
PASSED!
|
||||
# START (71) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (70) #############################
|
||||
PASSED!
|
||||
# START (69) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (68) #############################
|
||||
PASSED!
|
||||
# START (67) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (66) #############################
|
||||
PASSED!
|
||||
# START (65) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (64) #############################
|
||||
PASSED!
|
||||
# START (63) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (62) #############################
|
||||
PASSED!
|
||||
# START (61) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (60) #############################
|
||||
PASSED!
|
||||
# START (59) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (58) #############################
|
||||
PASSED!
|
||||
# START (57) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (56) #############################
|
||||
PASSED!
|
||||
# START (55) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (54) #############################
|
||||
PASSED!
|
||||
# START (53) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (52) #############################
|
||||
PASSED!
|
||||
# START (51) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (50) #############################
|
||||
PASSED!
|
||||
# START (49) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (48) #############################
|
||||
PASSED!
|
||||
# START (47) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (46) #############################
|
||||
PASSED!
|
||||
# START (45) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (44) #############################
|
||||
PASSED!
|
||||
# START (43) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (42) #############################
|
||||
PASSED!
|
||||
# START (41) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (40) #############################
|
||||
PASSED!
|
||||
# START (39) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (38) #############################
|
||||
PASSED!
|
||||
# START (37) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (36) #############################
|
||||
PASSED!
|
||||
# START (35) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (34) #############################
|
||||
PASSED!
|
||||
# START (33) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (32) #############################
|
||||
PASSED!
|
||||
# START (31) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (30) #############################
|
||||
PASSED!
|
||||
# START (29) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (28) #############################
|
||||
PASSED!
|
||||
# START (27) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (26) #############################
|
||||
PASSED!
|
||||
# START (25) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (24) #############################
|
||||
PASSED!
|
||||
# START (23) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (22) #############################
|
||||
PASSED!
|
||||
# START (21) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (20) #############################
|
||||
PASSED!
|
||||
# START (19) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (18) #############################
|
||||
PASSED!
|
||||
# START (17) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (16) #############################
|
||||
PASSED!
|
||||
# START (15) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (14) #############################
|
||||
PASSED!
|
||||
# START (13) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (12) #############################
|
||||
PASSED!
|
||||
# START (11) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (10) #############################
|
||||
PASSED!
|
||||
# START (9) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (8) #############################
|
||||
PASSED!
|
||||
# START (7) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (6) #############################
|
||||
PASSED!
|
||||
# START (5) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (4) #############################
|
||||
PASSED!
|
||||
# START (3) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (2) #############################
|
||||
PASSED!
|
||||
# START (1) #############################
|
||||
<rocTX "before hipLaunchKernel">
|
||||
<rocTX "hipLaunchKernel">
|
||||
<rocTX "after hipLaunchKernel">
|
||||
<rocTX "hipMemcpy">
|
||||
<rocTX "(null)">
|
||||
<rocTX "(null)">
|
||||
rocTX <"before hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"after hipLaunchKernel pid(22834) tid(22834)">
|
||||
rocTX <"hipMemcpy pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
rocTX <"(null) pid(22834) tid(22834)">
|
||||
PASSED!
|
||||
# START (0) #############################
|
||||
PASSED!
|
||||
|
||||
+307
-210
@@ -1,20 +1,21 @@
|
||||
ROCTracer (pid=26066):
|
||||
+ ROCP_FLUSH_RATE=100000 ./test/MatrixTranspose
|
||||
ROCTracer (pid=1991):
|
||||
ROCTracer: trace control flush rate(100000us)
|
||||
3802701299772587
|
||||
HIP-trace()
|
||||
ROCTracer (pid=26066):
|
||||
ROCTracer: trace control flush rate(100000us)
|
||||
HIP-trace()
|
||||
Device name Ellesmere [Radeon RX 470/480/570/570X/580/580X]
|
||||
Device name Device 687f
|
||||
## Iteration (99) #################
|
||||
43934932418043:43934932456496 26066:26066 hipGetDeviceProperties()
|
||||
43934934626423:43934934675542 26066:26066 hipMalloc(ptr(0x902800000) size(0x400000))
|
||||
43934934677103:43934934698784 26066:26066 hipMalloc(ptr(0x903000000) size(0x400000))
|
||||
43934934708976:43934940336620 26066:26066 hipMemcpy(dst(0x902800000) src(0x1384170) size(0x400000) kind(1))
|
||||
43934940338871:43934940338872 26066:26066 MARK(name(before HIP LaunchKernel))
|
||||
43935225511780:43935227349863 0:0 hcCommandKernel:6
|
||||
43935227358980:43935227395780 0:0 hcCommandMarker:8
|
||||
3802701304199730:3802701304207180 1991:1991 hipGetDeviceProperties(props=, device=0)
|
||||
3802701305255618:3802701305368889 1991:1991 hipMalloc(ptr=0x7fce16e0dec3, size=4194304)
|
||||
3802701305370969:3802701305429809 1991:1991 hipMalloc(ptr=0x7fffc1295178, size=4194304)
|
||||
PASSED!
|
||||
## Iteration (98) #################
|
||||
3802701580515709:3802701582582904 0:0 CopyHostToDevice:4:1991
|
||||
3802701583225872:3802701584425191 0:0 KernelExecution:8:1991
|
||||
3802701583217109:3802701586447303 0:0 CopyDeviceToHost:10:1991
|
||||
3802701594795564:3802701596533727 0:0 CopyHostToDevice:11:1991
|
||||
3802701596646592:3802701597848875 0:0 KernelExecution:15:1991
|
||||
3802701596604988:3802701599522360 0:0 CopyDeviceToHost:17:1991
|
||||
PASSED!
|
||||
## Iteration (97) #################
|
||||
PASSED!
|
||||
@@ -23,16 +24,6 @@ PASSED!
|
||||
## Iteration (95) #################
|
||||
PASSED!
|
||||
## Iteration (94) #################
|
||||
43935243433550:43935245268113 0:0 hcCommandKernel:11
|
||||
43935245270936:43935245302936 0:0 hcCommandMarker:13
|
||||
43935261086822:43935262934346 0:0 hcCommandKernel:16
|
||||
43935262937310:43935262969310 0:0 hcCommandMarker:18
|
||||
43935278843800:43935280686843 0:0 hcCommandKernel:21
|
||||
43935280690009:43935280722009 0:0 hcCommandMarker:23
|
||||
43935296495925:43935298337528 0:0 hcCommandKernel:26
|
||||
43935298340338:43935298371858 0:0 hcCommandMarker:28
|
||||
43935314291986:43935316140949 0:0 hcCommandKernel:31
|
||||
43935316144062:43935316175422 0:0 hcCommandMarker:33
|
||||
PASSED!
|
||||
## Iteration (93) #################
|
||||
PASSED!
|
||||
@@ -41,22 +32,34 @@ PASSED!
|
||||
## Iteration (91) #################
|
||||
PASSED!
|
||||
## Iteration (90) #################
|
||||
3802701606826614:3802701608688328 0:0 CopyHostToDevice:18:1991
|
||||
3802701608781496:3802701609988668 0:0 KernelExecution:22:1991
|
||||
3802701608758548:3802701611510159 0:0 CopyDeviceToHost:24:1991
|
||||
3802701618702082:3802701620571865 0:0 CopyHostToDevice:25:1991
|
||||
3802701620675087:3802701621878110 0:0 KernelExecution:29:1991
|
||||
3802701620650876:3802701623502597 0:0 CopyDeviceToHost:31:1991
|
||||
3802701630690881:3802701632557164 0:0 CopyHostToDevice:32:1991
|
||||
3802701632661061:3802701633864973 0:0 KernelExecution:36:1991
|
||||
3802701632637885:3802701635182424 0:0 CopyDeviceToHost:38:1991
|
||||
3802701642392578:3802701644307152 0:0 CopyHostToDevice:39:1991
|
||||
3802701644410516:3802701645608650 0:0 KernelExecution:43:1991
|
||||
3802701644387082:3802701647064112 0:0 CopyDeviceToHost:45:1991
|
||||
3802701654288485:3802701656163049 0:0 CopyHostToDevice:46:1991
|
||||
3802701656267334:3802701657467098 0:0 KernelExecution:50:1991
|
||||
3802701656244070:3802701658916870 0:0 CopyDeviceToHost:52:1991
|
||||
3802701666450396:3802701668378780 0:0 CopyHostToDevice:53:1991
|
||||
3802701668482438:3802701669683832 0:0 KernelExecution:57:1991
|
||||
3802701668458481:3802701671148361 0:0 CopyDeviceToHost:59:1991
|
||||
3802701678631556:3802701680505490 0:0 CopyHostToDevice:60:1991
|
||||
3802701680609945:3802701681806894 0:0 KernelExecution:64:1991
|
||||
3802701680586811:3802701683591443 0:0 CopyDeviceToHost:66:1991
|
||||
3802701691032768:3802701692918102 0:0 CopyHostToDevice:67:1991
|
||||
3802701693021896:3802701694223438 0:0 KernelExecution:71:1991
|
||||
3802701692999202:3802701695886464 0:0 CopyDeviceToHost:73:1991
|
||||
PASSED!
|
||||
## Iteration (89) #################
|
||||
43935332066943:43935333908066 0:0 hcCommandKernel:36
|
||||
43935333911153:43935333942513 0:0 hcCommandMarker:38
|
||||
43935350038934:43935351880697 0:0 hcCommandKernel:41
|
||||
43935351883641:43935351915001 0:0 hcCommandMarker:43
|
||||
43935367793257:43935369638700 0:0 hcCommandKernel:46
|
||||
43935369641744:43935369673104 0:0 hcCommandMarker:48
|
||||
43935385528005:43935387375368 0:0 hcCommandKernel:51
|
||||
43935387378362:43935387409722 0:0 hcCommandMarker:53
|
||||
43935403309412:43935405152295 0:0 hcCommandKernel:56
|
||||
43935405155209:43935405186569 0:0 hcCommandMarker:58
|
||||
PASSED!
|
||||
## Iteration (88) #################
|
||||
43935421119359:43935422961442 0:0 hcCommandKernel:61
|
||||
43935422964474:43935422995834 0:0 hcCommandMarker:63
|
||||
PASSED!
|
||||
## Iteration (87) #################
|
||||
PASSED!
|
||||
@@ -67,22 +70,34 @@ PASSED!
|
||||
## Iteration (84) #################
|
||||
PASSED!
|
||||
## Iteration (83) #################
|
||||
43935438844897:43935440686660 0:0 hcCommandKernel:66
|
||||
43935440689713:43935440721393 0:0 hcCommandMarker:68
|
||||
43935456490502:43935458334505 0:0 hcCommandKernel:71
|
||||
43935458337617:43935458368977 0:0 hcCommandMarker:73
|
||||
43935474147631:43935475986514 0:0 hcCommandKernel:76
|
||||
43935475989587:43935476020947 0:0 hcCommandMarker:78
|
||||
43935491854358:43935492341878 0:0 hcCommandKernel:81
|
||||
43935492345644:43935492352044 0:0 hcCommandMarker:83
|
||||
43935508126004:43935508605044 0:0 hcCommandKernel:86
|
||||
43935508608028:43935508614588 0:0 hcCommandMarker:88
|
||||
PASSED!
|
||||
## Iteration (82) #################
|
||||
43935524418876:43935524907836 0:0 hcCommandKernel:91
|
||||
43935524910557:43935524917117 0:0 hcCommandMarker:93
|
||||
PASSED!
|
||||
## Iteration (81) #################
|
||||
3802701703288299:3802701705170783 0:0 CopyHostToDevice:74:1991
|
||||
3802701705274243:3802701706486156 0:0 KernelExecution:78:1991
|
||||
3802701705250604:3802701707936074 0:0 CopyDeviceToHost:80:1991
|
||||
3802701715184407:3802701716946440 0:0 CopyHostToDevice:81:1991
|
||||
3802701717062173:3802701718258234 0:0 KernelExecution:85:1991
|
||||
3802701717027281:3802701719895352 0:0 CopyDeviceToHost:87:1991
|
||||
3802701727144976:3802701729139460 0:0 CopyHostToDevice:88:1991
|
||||
3802701729244175:3802701730445125 0:0 KernelExecution:92:1991
|
||||
3802701729220511:3802701732165583 0:0 CopyDeviceToHost:94:1991
|
||||
3802701739387037:3802701741142680 0:0 CopyHostToDevice:95:1991
|
||||
3802701741249310:3802701742453815 0:0 KernelExecution:99:1991
|
||||
3802701741225710:3802701744149042 0:0 CopyDeviceToHost:101:1991
|
||||
3802701751388465:3802701753137668 0:0 CopyHostToDevice:102:1991
|
||||
3802701753243075:3802701754440321 0:0 KernelExecution:106:1991
|
||||
3802701753219589:3802701756153951 0:0 CopyDeviceToHost:108:1991
|
||||
3802701763443335:3802701765498080 0:0 CopyHostToDevice:109:1991
|
||||
3802701765603802:3802701766820456 0:0 KernelExecution:113:1991
|
||||
3802701765580171:3802701768590463 0:0 CopyDeviceToHost:115:1991
|
||||
3802701775866137:3802701777758951 0:0 CopyHostToDevice:116:1991
|
||||
3802701777862528:3802701779073255 0:0 KernelExecution:120:1991
|
||||
3802701777839322:3802701780544442 0:0 CopyDeviceToHost:122:1991
|
||||
3802701787979987:3802701790138553 0:0 CopyHostToDevice:123:1991
|
||||
3802701790243940:3802701791446371 0:0 KernelExecution:127:1991
|
||||
3802701790220103:3802701792896973 0:0 CopyDeviceToHost:129:1991
|
||||
PASSED!
|
||||
## Iteration (80) #################
|
||||
PASSED!
|
||||
@@ -91,44 +106,47 @@ PASSED!
|
||||
## Iteration (78) #################
|
||||
PASSED!
|
||||
## Iteration (77) #################
|
||||
43935540719417:43935541208217 0:0 hcCommandKernel:96
|
||||
43935541211437:43935541217997 0:0 hcCommandMarker:98
|
||||
43935556967811:43935557454211 0:0 hcCommandKernel:101
|
||||
43935557457796:43935557464356 0:0 hcCommandMarker:103
|
||||
43935573251751:43935573737511 0:0 hcCommandKernel:106
|
||||
43935573740418:43935573746978 0:0 hcCommandMarker:108
|
||||
43935589528260:43935590013700 0:0 hcCommandKernel:111
|
||||
43935590017484:43935590024044 0:0 hcCommandMarker:113
|
||||
43935605722549:43935606210549 0:0 hcCommandKernel:116
|
||||
43935606213595:43935606220155 0:0 hcCommandMarker:118
|
||||
PASSED!
|
||||
## Iteration (76) #################
|
||||
43935621981951:43935622472991 0:0 hcCommandKernel:121
|
||||
43935622476644:43935622483204 0:0 hcCommandMarker:123
|
||||
PASSED!
|
||||
## Iteration (75) #################
|
||||
PASSED!
|
||||
## Iteration (74) #################
|
||||
PASSED!
|
||||
## Iteration (73) #################
|
||||
3802701800291738:3802701802179392 0:0 CopyHostToDevice:130:1991
|
||||
3802701802285163:3802701803481223 0:0 KernelExecution:134:1991
|
||||
3802701802261733:3802701804931343 0:0 CopyDeviceToHost:136:1991
|
||||
3802701812337128:3802701814252581 0:0 CopyHostToDevice:137:1991
|
||||
3802701814356366:3802701815565464 0:0 KernelExecution:141:1991
|
||||
3802701814332902:3802701817015292 0:0 CopyDeviceToHost:143:1991
|
||||
3802701824392847:3802701826310401 0:0 CopyHostToDevice:144:1991
|
||||
3802701826415256:3802701827613539 0:0 KernelExecution:148:1991
|
||||
3802701826391761:3802701829071431 0:0 CopyDeviceToHost:150:1991
|
||||
3802701836291435:3802701838179779 0:0 CopyHostToDevice:151:1991
|
||||
3802701838283081:3802701839480623 0:0 KernelExecution:155:1991
|
||||
3802701838259290:3802701840931690 0:0 CopyDeviceToHost:157:1991
|
||||
3802701848294054:3802701850186618 0:0 CopyHostToDevice:158:1991
|
||||
3802701850293201:3802701851487632 0:0 KernelExecution:162:1991
|
||||
3802701850269869:3802701852937908 0:0 CopyDeviceToHost:164:1991
|
||||
3802701860182332:3802701862143417 0:0 CopyHostToDevice:165:1991
|
||||
3802701862248805:3802701863444865 0:0 KernelExecution:169:1991
|
||||
3802701862224967:3802701865141909 0:0 CopyDeviceToHost:171:1991
|
||||
3802701872353003:3802701874265587 0:0 CopyHostToDevice:172:1991
|
||||
3802701874371291:3802701875572092 0:0 KernelExecution:176:1991
|
||||
3802701874348307:3802701877019147 0:0 CopyDeviceToHost:178:1991
|
||||
3802701884267750:3802701886153054 0:0 CopyHostToDevice:179:1991
|
||||
3802701886259179:3802701887463536 0:0 KernelExecution:183:1991
|
||||
3802701886235615:3802701888914085 0:0 CopyDeviceToHost:185:1991
|
||||
3802701896155929:3802701898142244 0:0 CopyHostToDevice:186:1991
|
||||
3802701898246687:3802701899454155 0:0 KernelExecution:190:1991
|
||||
3802701898223504:3802701901145246 0:0 CopyDeviceToHost:192:1991
|
||||
PASSED!
|
||||
## Iteration (72) #################
|
||||
PASSED!
|
||||
## Iteration (71) #################
|
||||
43935638193139:43935638675859 0:0 hcCommandKernel:126
|
||||
43935638678816:43935638685216 0:0 hcCommandMarker:128
|
||||
43935654459215:43935654944496 0:0 hcCommandKernel:131
|
||||
43935654952142:43935654958862 0:0 hcCommandMarker:133
|
||||
43935670702708:43935671183508 0:0 hcCommandKernel:136
|
||||
43935671186548:43935671193108 0:0 hcCommandMarker:138
|
||||
43935686939367:43935687417768 0:0 hcCommandKernel:141
|
||||
43935687425608:43935687432168 0:0 hcCommandMarker:143
|
||||
43935703168285:43935703658045 0:0 hcCommandKernel:146
|
||||
43935703661042:43935703667442 0:0 hcCommandMarker:148
|
||||
PASSED!
|
||||
## Iteration (70) #################
|
||||
43935719453292:43935719944172 0:0 hcCommandKernel:151
|
||||
43935719947859:43935719954419 0:0 hcCommandMarker:153
|
||||
PASSED!
|
||||
## Iteration (69) #################
|
||||
PASSED!
|
||||
@@ -139,20 +157,32 @@ PASSED!
|
||||
## Iteration (66) #################
|
||||
PASSED!
|
||||
## Iteration (65) #################
|
||||
43935735726735:43935736208335 0:0 hcCommandKernel:156
|
||||
43935736212026:43935736218586 0:0 hcCommandMarker:158
|
||||
43935751921190:43935752410790 0:0 hcCommandKernel:161
|
||||
43935752414441:43935752421001 0:0 hcCommandMarker:163
|
||||
43935768118205:43935768606045 0:0 hcCommandKernel:166
|
||||
43935768608995:43935768615555 0:0 hcCommandMarker:168
|
||||
43935784195088:43935784686608 0:0 hcCommandKernel:171
|
||||
43935784689436:43935784695996 0:0 hcCommandMarker:173
|
||||
43935800433600:43935800920160 0:0 hcCommandKernel:176
|
||||
43935800923246:43935800929646 0:0 hcCommandMarker:178
|
||||
3802701908363640:3802701910282004 0:0 CopyHostToDevice:193:1991
|
||||
3802701910388686:3802701911593636 0:0 KernelExecution:197:1991
|
||||
3802701910364944:3802701913041924 0:0 CopyDeviceToHost:199:1991
|
||||
3802701920274197:3802701922171761 0:0 CopyHostToDevice:200:1991
|
||||
3802701922278125:3802701923475222 0:0 KernelExecution:204:1991
|
||||
3802701922254592:3802701924925132 0:0 CopyDeviceToHost:206:1991
|
||||
3802701932168496:3802701934142771 0:0 CopyHostToDevice:207:1991
|
||||
3802701934246976:3802701935438295 0:0 KernelExecution:211:1991
|
||||
3802701934223551:3802701937141613 0:0 CopyDeviceToHost:213:1991
|
||||
3802701944352056:3802701946257570 0:0 CopyHostToDevice:214:1991
|
||||
3802701946362997:3802701947574317 0:0 KernelExecution:218:1991
|
||||
3802701946339571:3802701949023790 0:0 CopyDeviceToHost:220:1991
|
||||
3802701956400665:3802701958316110 0:0 CopyHostToDevice:221:1991
|
||||
3802701958422590:3802701959641615 0:0 KernelExecution:225:1991
|
||||
3802701958399130:3802701961106280 0:0 CopyDeviceToHost:227:1991
|
||||
3802701968320724:3802701970208178 0:0 CopyHostToDevice:228:1991
|
||||
3802701970318670:3802701971521693 0:0 KernelExecution:232:1991
|
||||
3802701970295529:3802701972971609 0:0 CopyDeviceToHost:234:1991
|
||||
3802701980199792:3802701982142436 0:0 CopyHostToDevice:235:1991
|
||||
3802701982245928:3802701983440062 0:0 KernelExecution:239:1991
|
||||
3802701982222487:3802701985143188 0:0 CopyDeviceToHost:241:1991
|
||||
3802701992355642:3802701994267646 0:0 CopyHostToDevice:242:1991
|
||||
3802701994371730:3802701995578753 0:0 KernelExecution:246:1991
|
||||
3802701994348667:3802701997026937 0:0 CopyDeviceToHost:248:1991
|
||||
PASSED!
|
||||
## Iteration (64) #################
|
||||
43935816699624:43935817182024 0:0 hcCommandKernel:181
|
||||
43935817187808:43935817194368 0:0 hcCommandMarker:183
|
||||
PASSED!
|
||||
## Iteration (63) #################
|
||||
PASSED!
|
||||
@@ -163,44 +193,47 @@ PASSED!
|
||||
## Iteration (60) #################
|
||||
PASSED!
|
||||
## Iteration (59) #################
|
||||
43935832969893:43935833459333 0:0 hcCommandKernel:186
|
||||
43935833462980:43935833469540 0:0 hcCommandMarker:188
|
||||
43935849246062:43935851077905 0:0 hcCommandKernel:191
|
||||
43935851080726:43935851112246 0:0 hcCommandMarker:193
|
||||
43935866982020:43935868823143 0:0 hcCommandKernel:196
|
||||
43935868826123:43935868857483 0:0 hcCommandMarker:198
|
||||
43935884647922:43935886487605 0:0 hcCommandKernel:201
|
||||
43935886490571:43935886521931 0:0 hcCommandMarker:203
|
||||
43935902402549:43935904242232 0:0 hcCommandKernel:206
|
||||
43935904245256:43935904276776 0:0 hcCommandMarker:208
|
||||
PASSED!
|
||||
## Iteration (58) #################
|
||||
43935920062038:43935921897081 0:0 hcCommandKernel:211
|
||||
43935921900164:43935921931524 0:0 hcCommandMarker:213
|
||||
PASSED!
|
||||
## Iteration (57) #################
|
||||
PASSED!
|
||||
## Iteration (56) #################
|
||||
3802702004315971:3802702006430907 0:0 CopyHostToDevice:249:1991
|
||||
3802702006513343:3802702007718885 0:0 KernelExecution:253:1991
|
||||
3802702006490217:3802702009041896 0:0 CopyDeviceToHost:255:1991
|
||||
3802702018262184:3802702019943876 0:0 CopyHostToDevice:256:1991
|
||||
3802702020050568:3802702021249295 0:0 KernelExecution:260:1991
|
||||
3802702020026907:3802702022584386 0:0 CopyDeviceToHost:262:1991
|
||||
3802702029541468:3802702031219270 0:0 CopyHostToDevice:263:1991
|
||||
3802702031312763:3802702032510305 0:0 KernelExecution:267:1991
|
||||
3802702031289161:3802702033843490 0:0 CopyDeviceToHost:269:1991
|
||||
3802702040805082:3802702042480244 0:0 CopyHostToDevice:270:1991
|
||||
3802702042572785:3802702043776105 0:0 KernelExecution:274:1991
|
||||
3802702042549004:3802702045110673 0:0 CopyDeviceToHost:276:1991
|
||||
3802702052065204:3802702053741167 0:0 CopyHostToDevice:277:1991
|
||||
3802702053835958:3802702055052463 0:0 KernelExecution:281:1991
|
||||
3802702053813487:3802702056374447 0:0 CopyDeviceToHost:283:1991
|
||||
3802702063333568:3802702065014061 0:0 CopyHostToDevice:284:1991
|
||||
3802702065111999:3802702066319615 0:0 KernelExecution:288:1991
|
||||
3802702065088771:3802702067654340 0:0 CopyDeviceToHost:290:1991
|
||||
3802702074618962:3802702076284625 0:0 CopyHostToDevice:291:1991
|
||||
3802702076384443:3802702077569835 0:0 KernelExecution:295:1991
|
||||
3802702076360685:3802702078904404 0:0 CopyDeviceToHost:297:1991
|
||||
3802702085881125:3802702087555758 0:0 CopyHostToDevice:298:1991
|
||||
3802702087649675:3802702088847958 0:0 KernelExecution:302:1991
|
||||
3802702087626608:3802702090183277 0:0 CopyDeviceToHost:304:1991
|
||||
3802702097151929:3802702098830722 0:0 CopyHostToDevice:305:1991
|
||||
3802702098924116:3802702100140473 0:0 KernelExecution:309:1991
|
||||
3802702098901192:3802702101472621 0:0 CopyDeviceToHost:311:1991
|
||||
PASSED!
|
||||
## Iteration (55) #################
|
||||
PASSED!
|
||||
## Iteration (54) #################
|
||||
PASSED!
|
||||
## Iteration (53) #################
|
||||
43935937812069:43935939657512 0:0 hcCommandKernel:216
|
||||
43935939660443:43935939691803 0:0 hcCommandMarker:218
|
||||
43935955484682:43935957328525 0:0 hcCommandKernel:221
|
||||
43935957331582:43935957362942 0:0 hcCommandMarker:223
|
||||
43935973218819:43935975058982 0:0 hcCommandKernel:226
|
||||
43935975061799:43935975093159 0:0 hcCommandMarker:228
|
||||
43935990920488:43935992758411 0:0 hcCommandKernel:231
|
||||
43935992761237:43935992792757 0:0 hcCommandMarker:233
|
||||
43936008544679:43936010384682 0:0 hcCommandKernel:236
|
||||
43936010389056:43936010420416 0:0 hcCommandMarker:238
|
||||
PASSED!
|
||||
## Iteration (52) #################
|
||||
43936026228358:43936028068841 0:0 hcCommandKernel:241
|
||||
43936028072005:43936028103685 0:0 hcCommandMarker:243
|
||||
PASSED!
|
||||
## Iteration (51) #################
|
||||
PASSED!
|
||||
@@ -211,20 +244,33 @@ PASSED!
|
||||
## Iteration (48) #################
|
||||
PASSED!
|
||||
## Iteration (47) #################
|
||||
43936043785925:43936045629448 0:0 hcCommandKernel:246
|
||||
43936045632305:43936045663985 0:0 hcCommandMarker:248
|
||||
43936061522848:43936063368291 0:0 hcCommandKernel:251
|
||||
43936063371344:43936063402864 0:0 hcCommandMarker:253
|
||||
43936079184681:43936081031404 0:0 hcCommandKernel:256
|
||||
43936081034470:43936081065830 0:0 hcCommandMarker:258
|
||||
43936096912019:43936098088660 0:0 hcCommandKernel:261
|
||||
43936098091778:43936098098338 0:0 hcCommandMarker:263
|
||||
43936113848983:43936114331063 0:0 hcCommandKernel:266
|
||||
43936114334738:43936114341298 0:0 hcCommandMarker:268
|
||||
3802702108615424:3802702110296796 0:0 CopyHostToDevice:312:1991
|
||||
3802702110392443:3802702111600207 0:0 KernelExecution:316:1991
|
||||
3802702110368957:3802702112934696 0:0 CopyDeviceToHost:318:1991
|
||||
3802702119898217:3802702121579670 0:0 CopyHostToDevice:319:1991
|
||||
3802702121673899:3802702122873960 0:0 KernelExecution:323:1991
|
||||
3802702121650880:3802702124193909 0:0 CopyDeviceToHost:325:1991
|
||||
3802702131156331:3802702132834494 0:0 CopyHostToDevice:326:1991
|
||||
3802702132927702:3802702134121984 0:0 KernelExecution:330:1991
|
||||
3802702132904324:3802702135456513 0:0 CopyDeviceToHost:332:1991
|
||||
3802702142434925:3802702144099207 0:0 CopyHostToDevice:333:1991
|
||||
3802702144200141:3802702145401090 0:0 KernelExecution:337:1991
|
||||
3802702144175248:3802702146735777 0:0 CopyDeviceToHost:339:1991
|
||||
3802702153706898:3802702155385711 0:0 CopyHostToDevice:340:1991
|
||||
3802702155488005:3802702156685843 0:0 KernelExecution:344:1991
|
||||
3802702155464581:3802702158018890 0:0 CopyDeviceToHost:346:1991
|
||||
3802702164987312:3802702166668385 0:0 CopyHostToDevice:347:1991
|
||||
3802702166762069:3802702167965537 0:0 KernelExecution:351:1991
|
||||
3802702166739105:3802702169298644 0:0 CopyDeviceToHost:353:1991
|
||||
3802702176260016:3802702177933188 0:0 CopyHostToDevice:354:1991
|
||||
3802702178026430:3802702179223971 0:0 KernelExecution:358:1991
|
||||
3802702178002518:3802702180540757 0:0 CopyDeviceToHost:360:1991
|
||||
3802702187490789:3802702189167931 0:0 CopyHostToDevice:361:1991
|
||||
3802702189262737:3802702190474501 0:0 KernelExecution:365:1991
|
||||
3802702189239082:3802702191808141 0:0 CopyDeviceToHost:367:1991
|
||||
3802702198761922:3802702200425845 0:0 CopyHostToDevice:368:1991
|
||||
PASSED!
|
||||
## Iteration (46) #################
|
||||
43936130207157:43936130701557 0:0 hcCommandKernel:271
|
||||
43936130704352:43936130710912 0:0 hcCommandMarker:273
|
||||
PASSED!
|
||||
## Iteration (45) #################
|
||||
PASSED!
|
||||
@@ -235,44 +281,47 @@ PASSED!
|
||||
## Iteration (42) #################
|
||||
PASSED!
|
||||
## Iteration (41) #################
|
||||
43936146563182:43936147046062 0:0 hcCommandKernel:276
|
||||
43936147049151:43936147055711 0:0 hcCommandMarker:278
|
||||
43936162894728:43936163374888 0:0 hcCommandKernel:281
|
||||
43936163377872:43936163384592 0:0 hcCommandMarker:283
|
||||
43936179200342:43936179687382 0:0 hcCommandKernel:286
|
||||
43936179691196:43936179697756 0:0 hcCommandMarker:288
|
||||
43936195476376:43936195958456 0:0 hcCommandKernel:291
|
||||
43936195961532:43936195968092 0:0 hcCommandMarker:293
|
||||
43936211754702:43936212238862 0:0 hcCommandKernel:296
|
||||
43936212241993:43936212248553 0:0 hcCommandMarker:298
|
||||
PASSED!
|
||||
## Iteration (40) #################
|
||||
43936228051680:43936228530400 0:0 hcCommandKernel:301
|
||||
43936228534046:43936228540606 0:0 hcCommandMarker:303
|
||||
PASSED!
|
||||
## Iteration (39) #################
|
||||
PASSED!
|
||||
## Iteration (38) #################
|
||||
3802702200526879:3802702201738792 0:0 KernelExecution:372:1991
|
||||
3802702200502735:3802702203073505 0:0 CopyDeviceToHost:374:1991
|
||||
3802702210101096:3802702211781099 0:0 CopyHostToDevice:375:1991
|
||||
3802702211874278:3802702213070339 0:0 KernelExecution:379:1991
|
||||
3802702211851149:3802702214405528 0:0 CopyDeviceToHost:381:1991
|
||||
3802702221371170:3802702223046872 0:0 CopyHostToDevice:382:1991
|
||||
3802702223141537:3802702224348264 0:0 KernelExecution:386:1991
|
||||
3802702223118273:3802702225680452 0:0 CopyDeviceToHost:388:1991
|
||||
3802702232644404:3802702234313936 0:0 CopyHostToDevice:389:1991
|
||||
3802702234409358:3802702235607788 0:0 KernelExecution:393:1991
|
||||
3802702234385867:3802702236943196 0:0 CopyDeviceToHost:395:1991
|
||||
3802702243900787:3802702245580279 0:0 CopyHostToDevice:396:1991
|
||||
3802702245674663:3802702246878279 0:0 KernelExecution:400:1991
|
||||
3802702245651760:3802702248198969 0:0 CopyDeviceToHost:402:1991
|
||||
3802702255168930:3802702256847073 0:0 CopyHostToDevice:403:1991
|
||||
3802702256941454:3802702258155589 0:0 KernelExecution:407:1991
|
||||
3802702256918733:3802702259489683 0:0 CopyDeviceToHost:409:1991
|
||||
3802702266456174:3802702268121957 0:0 CopyHostToDevice:410:1991
|
||||
3802702268222984:3802702269419637 0:0 KernelExecution:414:1991
|
||||
3802702268198287:3802702270718936 0:0 CopyDeviceToHost:416:1991
|
||||
3802702277684438:3802702279355020 0:0 CopyHostToDevice:417:1991
|
||||
3802702279449065:3802702280656977 0:0 KernelExecution:421:1991
|
||||
3802702279425380:3802702281990519 0:0 CopyDeviceToHost:423:1991
|
||||
3802702288963001:3802702290626813 0:0 CopyHostToDevice:424:1991
|
||||
3802702290725647:3802702291916077 0:0 KernelExecution:428:1991
|
||||
3802702290702274:3802702293249973 0:0 CopyDeviceToHost:430:1991
|
||||
3802702300213905:3802702301888607 0:0 CopyHostToDevice:431:1991
|
||||
PASSED!
|
||||
## Iteration (37) #################
|
||||
PASSED!
|
||||
## Iteration (36) #################
|
||||
PASSED!
|
||||
## Iteration (35) #################
|
||||
43936244268347:43936244752187 0:0 hcCommandKernel:306
|
||||
43936244759707:43936244766107 0:0 hcCommandMarker:308
|
||||
43936260465746:43936260949906 0:0 hcCommandKernel:311
|
||||
43936260953781:43936260960181 0:0 hcCommandMarker:313
|
||||
43936276704103:43936277186183 0:0 hcCommandKernel:316
|
||||
43936277189819:43936277196379 0:0 hcCommandMarker:318
|
||||
43936292908367:43936293394927 0:0 hcCommandKernel:321
|
||||
43936293398665:43936293405065 0:0 hcCommandMarker:323
|
||||
43936309159941:43936309655781 0:0 hcCommandKernel:326
|
||||
43936309658663:43936309665223 0:0 hcCommandMarker:328
|
||||
PASSED!
|
||||
## Iteration (34) #################
|
||||
43936325491676:43936325977116 0:0 hcCommandKernel:331
|
||||
43936325980102:43936325986662 0:0 hcCommandMarker:333
|
||||
PASSED!
|
||||
## Iteration (33) #################
|
||||
PASSED!
|
||||
@@ -283,20 +332,34 @@ PASSED!
|
||||
## Iteration (30) #################
|
||||
PASSED!
|
||||
## Iteration (29) #################
|
||||
43936341856430:43936342339790 0:0 hcCommandKernel:336
|
||||
43936342342883:43936342349283 0:0 hcCommandMarker:338
|
||||
43936358065666:43936358544706 0:0 hcCommandKernel:341
|
||||
43936358548573:43936358554973 0:0 hcCommandMarker:343
|
||||
43936374226834:43936374711954 0:0 hcCommandKernel:346
|
||||
43936374714957:43936374721517 0:0 hcCommandMarker:348
|
||||
43936390393107:43936390876947 0:0 hcCommandKernel:351
|
||||
43936390879989:43936390886549 0:0 hcCommandMarker:353
|
||||
43936406478567:43936406968327 0:0 hcCommandKernel:356
|
||||
43936406971190:43936406977750 0:0 hcCommandMarker:358
|
||||
3802702301982442:3802702303186799 0:0 KernelExecution:435:1991
|
||||
3802702301959178:3802702304503997 0:0 CopyDeviceToHost:437:1991
|
||||
3802702311466108:3802702313146390 0:0 CopyHostToDevice:438:1991
|
||||
3802702313238825:3802702314439626 0:0 KernelExecution:442:1991
|
||||
3802702313215791:3802702315773720 0:0 CopyDeviceToHost:444:1991
|
||||
3802702322736361:3802702324399864 0:0 CopyHostToDevice:445:1991
|
||||
3802702324503098:3802702325721085 0:0 KernelExecution:449:1991
|
||||
3802702324478794:3802702327055594 0:0 CopyDeviceToHost:451:1991
|
||||
3802702334030715:3802702335709388 0:0 CopyHostToDevice:452:1991
|
||||
3802702335806620:3802702337014532 0:0 KernelExecution:456:1991
|
||||
3802702335783968:3802702338348468 0:0 CopyDeviceToHost:458:1991
|
||||
3802702345327399:3802702347004601 0:0 CopyHostToDevice:459:1991
|
||||
3802702347117082:3802702348318476 0:0 KernelExecution:463:1991
|
||||
3802702347074012:3802702349651691 0:0 CopyDeviceToHost:465:1991
|
||||
3802702356616483:3802702358289405 0:0 CopyHostToDevice:466:1991
|
||||
3802702358382881:3802702359585164 0:0 KernelExecution:470:1991
|
||||
3802702358359406:3802702360920335 0:0 CopyDeviceToHost:472:1991
|
||||
3802702367904117:3802702369585909 0:0 CopyHostToDevice:473:1991
|
||||
3802702369679903:3802702370875371 0:0 KernelExecution:477:1991
|
||||
3802702369656630:3802702372196308 0:0 CopyDeviceToHost:479:1991
|
||||
3802702379156600:3802702380837792 0:0 CopyHostToDevice:480:1991
|
||||
3802702380930326:3802702382134830 0:0 KernelExecution:484:1991
|
||||
3802702380907402:3802702383472292 0:0 CopyDeviceToHost:486:1991
|
||||
3802702390441713:3802702392106996 0:0 CopyHostToDevice:487:1991
|
||||
3802702392207713:3802702393417847 0:0 KernelExecution:491:1991
|
||||
3802702392183556:3802702394752325 0:0 CopyDeviceToHost:493:1991
|
||||
PASSED!
|
||||
## Iteration (28) #################
|
||||
43936422759883:43936423242603 0:0 hcCommandKernel:361
|
||||
43936423245282:43936423251842 0:0 hcCommandMarker:363
|
||||
PASSED!
|
||||
## Iteration (27) #################
|
||||
PASSED!
|
||||
@@ -307,44 +370,47 @@ PASSED!
|
||||
## Iteration (24) #################
|
||||
PASSED!
|
||||
## Iteration (23) #################
|
||||
43936439030746:43936439514266 0:0 hcCommandKernel:366
|
||||
43936439518052:43936439524612 0:0 hcCommandMarker:368
|
||||
43936455234140:43936455719900 0:0 hcCommandKernel:371
|
||||
43936455722741:43936455729141 0:0 hcCommandMarker:373
|
||||
43936471535617:43936473377220 0:0 hcCommandKernel:376
|
||||
43936473379982:43936473411502 0:0 hcCommandMarker:378
|
||||
43936489194662:43936491033065 0:0 hcCommandKernel:381
|
||||
43936491035944:43936491067304 0:0 hcCommandMarker:383
|
||||
43936506844418:43936508676581 0:0 hcCommandKernel:386
|
||||
43936508679657:43936508711177 0:0 hcCommandMarker:388
|
||||
PASSED!
|
||||
## Iteration (22) #################
|
||||
43936524587883:43936526420846 0:0 hcCommandKernel:391
|
||||
43936526423835:43936526455195 0:0 hcCommandMarker:393
|
||||
PASSED!
|
||||
## Iteration (21) #################
|
||||
PASSED!
|
||||
## Iteration (20) #################
|
||||
3802702401709737:3802702403387670 0:0 CopyHostToDevice:494:1991
|
||||
3802702403489293:3802702404695872 0:0 KernelExecution:498:1991
|
||||
3802702403465280:3802702406030229 0:0 CopyDeviceToHost:500:1991
|
||||
3802702412982171:3802702414646163 0:0 CopyHostToDevice:501:1991
|
||||
3802702414739104:3802702415951461 0:0 KernelExecution:505:1991
|
||||
3802702414715973:3802702417282642 0:0 CopyDeviceToHost:507:1991
|
||||
3802702424250984:3802702425925207 0:0 CopyHostToDevice:508:1991
|
||||
3802702426022614:3802702427240009 0:0 KernelExecution:512:1991
|
||||
3802702425999277:3802702428556726 0:0 CopyDeviceToHost:514:1991
|
||||
3802702435521608:3802702437497583 0:0 CopyHostToDevice:515:1991
|
||||
3802702437591756:3802702438798483 0:0 KernelExecution:519:1991
|
||||
3802702437567843:3802702440117692 0:0 CopyDeviceToHost:521:1991
|
||||
3802702447076184:3802702448752496 0:0 CopyHostToDevice:522:1991
|
||||
3802702448844326:3802702450040979 0:0 KernelExecution:526:1991
|
||||
3802702448821457:3802702451374905 0:0 CopyDeviceToHost:528:1991
|
||||
3802702458338087:3802702460115460 0:0 CopyHostToDevice:529:1991
|
||||
3802702460219046:3802702461421625 0:0 KernelExecution:533:1991
|
||||
3802702460192041:3802702462758090 0:0 CopyDeviceToHost:535:1991
|
||||
3802702469730872:3802702471408304 0:0 CopyHostToDevice:536:1991
|
||||
3802702471502923:3802702472699724 0:0 KernelExecution:540:1991
|
||||
3802702471478905:3802702474035724 0:0 CopyDeviceToHost:542:1991
|
||||
3802702481000815:3802702482659947 0:0 CopyHostToDevice:543:1991
|
||||
3802702482757759:3802702483952190 0:0 KernelExecution:547:1991
|
||||
3802702482734898:3802702485283566 0:0 CopyDeviceToHost:549:1991
|
||||
3802702492244298:3802702493917401 0:0 CopyHostToDevice:550:1991
|
||||
3802702494011385:3802702495222705 0:0 KernelExecution:554:1991
|
||||
3802702493988441:3802702496538570 0:0 CopyDeviceToHost:556:1991
|
||||
PASSED!
|
||||
## Iteration (19) #################
|
||||
PASSED!
|
||||
## Iteration (18) #################
|
||||
PASSED!
|
||||
## Iteration (17) #################
|
||||
43936542246761:43936544088524 0:0 hcCommandKernel:396
|
||||
43936544091588:43936544123268 0:0 hcCommandMarker:398
|
||||
43936559948159:43936561794402 0:0 hcCommandKernel:401
|
||||
43936561797239:43936561828759 0:0 hcCommandMarker:403
|
||||
43936577605213:43936579448896 0:0 hcCommandKernel:406
|
||||
43936579451894:43936579483254 0:0 hcCommandMarker:408
|
||||
43936595369090:43936597208613 0:0 hcCommandKernel:411
|
||||
43936597211572:43936597242932 0:0 hcCommandMarker:413
|
||||
43936613017192:43936614856075 0:0 hcCommandKernel:416
|
||||
43936614859107:43936614890467 0:0 hcCommandMarker:418
|
||||
PASSED!
|
||||
## Iteration (16) #################
|
||||
43936630770153:43936632618476 0:0 hcCommandKernel:421
|
||||
43936632621411:43936632653091 0:0 hcCommandMarker:423
|
||||
PASSED!
|
||||
## Iteration (15) #################
|
||||
PASSED!
|
||||
@@ -353,18 +419,35 @@ PASSED!
|
||||
## Iteration (13) #################
|
||||
PASSED!
|
||||
## Iteration (12) #################
|
||||
43936648421451:43936650272014 0:0 hcCommandKernel:426
|
||||
43936650274717:43936650306397 0:0 hcCommandMarker:428
|
||||
43936666186176:43936668028259 0:0 hcCommandKernel:431
|
||||
43936668031033:43936668062553 0:0 hcCommandMarker:433
|
||||
43936683847105:43936685694788 0:0 hcCommandKernel:436
|
||||
43936685697850:43936685729530 0:0 hcCommandMarker:438
|
||||
43936701611894:43936703454617 0:0 hcCommandKernel:441
|
||||
43936703457617:43936703488977 0:0 hcCommandMarker:443
|
||||
3802702503514682:3802702505171794 0:0 CopyHostToDevice:557:1991
|
||||
3802702505267652:3802702506468157 0:0 KernelExecution:561:1991
|
||||
3802702505243905:3802702507802814 0:0 CopyDeviceToHost:563:1991
|
||||
3802702514761386:3802702516425008 0:0 CopyHostToDevice:564:1991
|
||||
3802702516524080:3802702517731252 0:0 KernelExecution:568:1991
|
||||
3802702516500289:3802702519068477 0:0 CopyDeviceToHost:570:1991
|
||||
3802702526022439:3802702527700141 0:0 CopyHostToDevice:571:1991
|
||||
3802702527794104:3802702528982164 0:0 KernelExecution:575:1991
|
||||
3802702527771042:3802702530315231 0:0 CopyDeviceToHost:577:1991
|
||||
3802702537274272:3802702538953635 0:0 CopyHostToDevice:578:1991
|
||||
3802702539050334:3802702540254987 0:0 KernelExecution:582:1991
|
||||
3802702539025425:3802702541587134 0:0 CopyDeviceToHost:584:1991
|
||||
3802702548553016:3802702550225609 0:0 CopyHostToDevice:585:1991
|
||||
3802702550319337:3802702551518805 0:0 KernelExecution:589:1991
|
||||
3802702550295569:3802702552853758 0:0 CopyDeviceToHost:591:1991
|
||||
3802702559816479:3802702561495482 0:0 CopyHostToDevice:592:1991
|
||||
3802702561589855:3802702562788137 0:0 KernelExecution:596:1991
|
||||
3802702561565542:3802702564108601 0:0 CopyDeviceToHost:598:1991
|
||||
3802702571069693:3802702572746995 0:0 CopyHostToDevice:599:1991
|
||||
3802702572840650:3802702574041747 0:0 KernelExecution:603:1991
|
||||
3802702572817856:3802702575375565 0:0 CopyDeviceToHost:605:1991
|
||||
3802702582343137:3802702584028249 0:0 CopyHostToDevice:606:1991
|
||||
3802702584131111:3802702585314874 0:0 KernelExecution:610:1991
|
||||
3802702584098390:3802702586648988 0:0 CopyDeviceToHost:612:1991
|
||||
3802702593620890:3802702595300582 0:0 CopyHostToDevice:613:1991
|
||||
3802702595394737:3802702596603391 0:0 KernelExecution:617:1991
|
||||
3802702595371233:3802702597936882 0:0 CopyDeviceToHost:619:1991
|
||||
PASSED!
|
||||
## Iteration (11) #################
|
||||
43936719264608:43936719749728 0:0 hcCommandKernel:446
|
||||
43936719752843:43936719759403 0:0 hcCommandMarker:448
|
||||
PASSED!
|
||||
## Iteration (10) #################
|
||||
PASSED!
|
||||
@@ -377,36 +460,50 @@ PASSED!
|
||||
## Iteration (6) #################
|
||||
PASSED!
|
||||
## Iteration (5) #################
|
||||
43936735528823:43936736005623 0:0 hcCommandKernel:451
|
||||
43936736008904:43936736015464 0:0 hcCommandMarker:453
|
||||
43936751784154:43936752265434 0:0 hcCommandKernel:456
|
||||
43936752268477:43936752274877 0:0 hcCommandMarker:458
|
||||
43936768038508:43936768522508 0:0 hcCommandKernel:461
|
||||
43936768526347:43936768532907 0:0 hcCommandMarker:463
|
||||
43936784289295:43936784779215 0:0 hcCommandKernel:466
|
||||
43936784782982:43936784789542 0:0 hcCommandMarker:468
|
||||
43936800538297:43936801016857 0:0 hcCommandKernel:471
|
||||
43936801019748:43936801026468 0:0 hcCommandMarker:473
|
||||
PASSED!
|
||||
## Iteration (4) #################
|
||||
43936816815614:43936817294654 0:0 hcCommandKernel:476
|
||||
43936817297320:43936817303880 0:0 hcCommandMarker:478
|
||||
PASSED!
|
||||
## Iteration (3) #################
|
||||
3802702605023015:3802702606699537 0:0 CopyHostToDevice:620:1991
|
||||
3802702606793386:3802702607994484 0:0 KernelExecution:624:1991
|
||||
3802702606770418:3802702609331847 0:0 CopyDeviceToHost:626:1991
|
||||
3802702616295619:3802702617971351 0:0 CopyHostToDevice:627:1991
|
||||
3802702618064582:3802702619276198 0:0 KernelExecution:631:1991
|
||||
3802702618041252:3802702620593170 0:0 CopyDeviceToHost:633:1991
|
||||
3802702627572022:3802702629249514 0:0 CopyHostToDevice:634:1991
|
||||
3802702629343204:3802702630550228 0:0 KernelExecution:638:1991
|
||||
3802702629319715:3802702631886524 0:0 CopyDeviceToHost:640:1991
|
||||
3802702638854896:3802702640514568 0:0 CopyHostToDevice:641:1991
|
||||
3802702640601153:3802702641794250 0:0 KernelExecution:645:1991
|
||||
3802702640583338:3802702643131137 0:0 CopyDeviceToHost:647:1991
|
||||
3802702650106259:3802702651784942 0:0 CopyHostToDevice:648:1991
|
||||
3802702651876671:3802702653079250 0:0 KernelExecution:652:1991
|
||||
3802702651853582:3802702654414351 0:0 CopyDeviceToHost:654:1991
|
||||
3802702661383522:3802702663061155 0:0 CopyHostToDevice:655:1991
|
||||
3802702663154356:3802702664347453 0:0 KernelExecution:659:1991
|
||||
3802702663130645:3802702665680984 0:0 CopyDeviceToHost:661:1991
|
||||
3802702672630496:3802702674303238 0:0 CopyHostToDevice:662:1991
|
||||
3802702674398093:3802702675599190 0:0 KernelExecution:666:1991
|
||||
3802702674374489:3802702676932868 0:0 CopyDeviceToHost:668:1991
|
||||
3802702683898880:3802702685606503 0:0 CopyHostToDevice:669:1991
|
||||
3802702685701165:3802702686898410 0:0 KernelExecution:673:1991
|
||||
3802702685678193:3802702688219002 0:0 CopyDeviceToHost:675:1991
|
||||
3802702695162453:3802702696838515 0:0 CopyHostToDevice:676:1991
|
||||
3802702696932444:3802702698137097 0:0 KernelExecution:680:1991
|
||||
3802702696909796:3802702699473165 0:0 CopyDeviceToHost:682:1991
|
||||
PASSED!
|
||||
## Iteration (2) #################
|
||||
PASSED!
|
||||
## Iteration (1) #################
|
||||
PASSED!
|
||||
## Iteration (0) #################
|
||||
43936833089833:43936833579433 0:0 hcCommandKernel:481
|
||||
43936833582286:43936833588846 0:0 hcCommandMarker:483
|
||||
43936849646904:43936850132504 0:0 hcCommandKernel:486
|
||||
43936850135326:43936850141886 0:0 hcCommandMarker:488
|
||||
43936867294430:43936867780350 0:0 hcCommandKernel:491
|
||||
43936867783055:43936867789615 0:0 hcCommandMarker:493
|
||||
43936884613213:43936885103133 0:0 hcCommandKernel:496
|
||||
43936885106028:43936885112748 0:0 hcCommandMarker:498
|
||||
43936901844607:43936902331647 0:0 hcCommandKernel:501
|
||||
43936902334630:43936902341030 0:0 hcCommandMarker:503
|
||||
PASSED!
|
||||
3802702706580728:3802702708245350 0:0 CopyHostToDevice:683:1991
|
||||
3802702708346791:3802702709549370 0:0 KernelExecution:687:1991
|
||||
3802702708322181:3802702710885410 0:0 CopyDeviceToHost:689:1991
|
||||
3802702717849822:3802702719525044 0:0 CopyHostToDevice:690:1991
|
||||
3802702719618857:3802702720813139 0:0 KernelExecution:694:1991
|
||||
3802702719594825:3802702722149644 0:0 CopyDeviceToHost:696:1991
|
||||
3802702729111215:3802702730788167 0:0 CopyHostToDevice:697:1991
|
||||
3802702730881622:3802702732076497 0:0 KernelExecution:701:1991
|
||||
3802702730858498:3802702733412517 0:0 CopyDeviceToHost:703:1991
|
||||
|
||||
+281
-241
@@ -1,10 +1,9 @@
|
||||
ROCTracer (pid=26055):
|
||||
+ ROCP_CTRL_RATE=10:100000:1000000 ./test/MatrixTranspose
|
||||
ROCTracer (pid=1983):
|
||||
ROCTracer: trace control: delay(10us), length(100000us), rate(1000000us)
|
||||
3802699747119708
|
||||
HIP-trace()
|
||||
ROCTracer (pid=26055):
|
||||
ROCTracer: trace control: delay(10us), length(100000us), rate(1000000us)
|
||||
HIP-trace()
|
||||
Device name Ellesmere [Radeon RX 470/480/570/570X/580/580X]
|
||||
Device name Device 687f
|
||||
## Iteration (99) #################
|
||||
PASSED!
|
||||
## Iteration (98) #################
|
||||
@@ -205,239 +204,280 @@ PASSED!
|
||||
PASSED!
|
||||
## Iteration (0) #################
|
||||
PASSED!
|
||||
43932016356046:43932016397500 26055:26055 hipGetDeviceProperties()
|
||||
43932018579649:43932018627633 26055:26055 hipMalloc(ptr(0x903400000) size(0x400000))
|
||||
43932018629101:43932018648692 26055:26055 hipMalloc(ptr(0x903c00000) size(0x400000))
|
||||
43932018657045:43932024206624 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43932024210084:43932024210085 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932309367516:43932309367517 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932325768070:43932325768071 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932325806211:43932325806212 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932342067435:43932342067436 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932342101677:43932342101678 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932358360160:43932358360161 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932358394862:43932358394863 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932374818865:43932374818866 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932374857099:43932374857100 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932392553937:43932392553938 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932392587074:43932392587075 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932410322278:43932410322279 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932410356222:43932410356223 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932428013622:43932428013623 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932428047370:43932428047371 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932445823875:43932445823876 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932445858364:43932445858365 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932463522521:43932463522522 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932463556106:43932463556107 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932481264157:43932481264158 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932481302264:43932481302265 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932498957147:43932498957148 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932499007307:43932499007308 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932516701532:43932516701533 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932516740634:43932516740635 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932534396161:43932534396162 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932534430109:43932534430110 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932552136507:43932552136508 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932552174955:43932552174956 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932569838372:43932569838373 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932569873357:43932569873358 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932587582936:43932587582937 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932587616530:43932587616531 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932605271897:43932605271898 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932605306872:43932605306873 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932623037986:43932623037987 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932623072073:43932623072074 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932640747873:43932640747874 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932640782515:43932640782516 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932657068887:43932657068888 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932657102762:43932657102763 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932673379533:43932673379534 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932673413702:43932673413703 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932689650275:43932689650276 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932689688120:43932689688121 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932706024306:43932706024307 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932706061892:43932706061893 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932722404114:43932722404115 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932722450953:43932722450954 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932738747072:43932738747073 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932738783895:43932738783896 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932755053911:43932755053912 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932755086752:43932755086753 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932771329207:43932771329208 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932771347101:43932771347102 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932787609603:43932787609604 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932787626372:43932787626373 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932803880283:43932803880284 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932803913740:43932803913741 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932820132122:43932820132123 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932820170233:43932820170234 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932836497613:43932836497614 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932836535605:43932836535606 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932852904822:43932852904823 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932852942407:43932852942408 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932869290524:43932869290525 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932869329866:43932869329867 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932885635307:43932885635308 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932885669256:43932885669257 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932901970155:43932901970156 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932901989697:43932901989698 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932918260839:43932918260840 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932918293762:43932918293763 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932934545610:43932934545611 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932934577595:43932934577596 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932950855037:43932950855038 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932950906554:43932950906555 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932967158140:43932967158141 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932967204959:43932967204960 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932983443711:43932983443712 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932983481045:43932983481046 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932998919789:43932999777243 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43932999778933:43932999778934 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43932999790858:43932999857966 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43932999869719:43932999869720 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43932999871831:43933002727304 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933016724230:43933017583617 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43933017585152:43933017585153 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933017597371:43933017637628 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43933017639250:43933017639251 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933017641217:43933020520010 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933034542756:43933035404131 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43933035405703:43933035405704 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933035417664:43933035457991 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43933035459677:43933035459678 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933035461554:43933038337624 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933052293417:43933053160408 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43933053162015:43933053162016 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933053174382:43933053196225 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43933053198167:43933053198168 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933053200026:43933056101223 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933070121982:43933070978773 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43933070980262:43933070980263 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933070997704:43933071038037 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43933071039939:43933071039940 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933071041871:43933073922115 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933087857070:43933088762523 26055:26055 hipMemcpy(dst(0x903400000) src(0x25fd170) size(0x400000) kind(1))
|
||||
43933088764032:43933088764033 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933088775969:43933088816379 26055:26055 hipModuleLaunchKernel(kernel(matrixTranspose(float*, float*, int)) stream((nil)))
|
||||
43933088818233:43933088818234 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933088830023:43933091723027 26055:26055 hipMemcpy(dst(0x29fd180) src(0x903c00000) size(0x400000) kind(2))
|
||||
43933106593182:43933106593183 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933106631182:43933106631183 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933124264790:43933124264791 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933124299416:43933124299417 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933141986334:43933141986335 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933142020652:43933142020653 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933159656263:43933159656264 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933159689392:43933159689393 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933177421632:43933177421633 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933177460424:43933177460425 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933195118213:43933195118214 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933195156305:43933195156306 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933212858769:43933212858770 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933212892428:43933212892429 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933230550599:43933230550600 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933230584794:43933230584795 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933248275723:43933248275724 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933248310176:43933248310177 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933264626153:43933264626154 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933264665629:43933264665630 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933280992560:43933280992561 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933281027422:43933281027423 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933297321505:43933297321506 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933297359452:43933297359453 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933313662994:43933313662995 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933313700705:43933313700706 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933329971419:43933329971420 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933330018417:43933330018418 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933346273054:43933346273055 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933346306837:43933346306838 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933362521760:43933362521761 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933362540391:43933362540392 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933378827233:43933378827234 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933378845241:43933378845242 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933395183216:43933395183217 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933395215386:43933395215387 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933411559286:43933411559287 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933411596821:43933411596822 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933427865512:43933427865513 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933427898752:43933427898753 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933444147624:43933444147625 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933444175808:43933444175809 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933460414293:43933460414294 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933460446208:43933460446209 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933476718044:43933476718045 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933476749715:43933476749716 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933492989969:43933492989970 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933493020764:43933493020765 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933509257931:43933509257932 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933509289509:43933509289510 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933525557224:43933525557225 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933525588932:43933525588933 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933541884683:43933541884684 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933541916037:43933541916038 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933558234802:43933558234803 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933558266471:43933558266472 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933574598996:43933574598997 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933574630471:43933574630472 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933590916499:43933590916500 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933590946901:43933590946902 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933607216207:43933607216208 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933607247236:43933607247237 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933624120350:43933624120351 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933624138017:43933624138018 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933641790135:43933641790136 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933641807143:43933641807144 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933659509173:43933659509174 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933659526749:43933659526750 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933677219727:43933677219728 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933677254061:43933677254062 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933694974650:43933694974651 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933695009347:43933695009348 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933712659673:43933712659674 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933712708655:43933712708656 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933730412868:43933730412869 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933730446931:43933730446932 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933748101862:43933748101863 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933748139940:43933748139941 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933765877856:43933765877857 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933765916382:43933765916383 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933783570361:43933783570362 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933783603616:43933783603617 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933801334338:43933801334339 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933801368467:43933801368468 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933819035225:43933819035226 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933819068314:43933819068315 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933836809157:43933836809158 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933836847860:43933836847861 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933854512746:43933854512747 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933854546024:43933854546025 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933872241982:43933872241983 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933872276613:43933872276614 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933888625718:43933888625719 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933888659297:43933888659298 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933904989760:43933904989761 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933905023554:43933905023555 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933921307079:43933921307080 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933921344505:43933921344506 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933937634499:43933937634500 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933937681958:43933937681959 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933953935834:43933953935835 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933953973608:43933953973609 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933970237558:43933970237559 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933970274704:43933970274705 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43933986518798:43933986518799 26055:26055 MARK(name(before HIP LaunchKernel))
|
||||
43933986551047:43933986551048 26055:26055 MARK(name(after HIP LaunchKernel))
|
||||
43934001936907:43934002013320 26055:26055 hipFree(ptr(0x903400000))
|
||||
43934002015215:43934002031122 26055:26055 hipFree(ptr(0x903c00000))
|
||||
43932999861577:43933001699020 0:0 hcCommandKernel:89
|
||||
43933001702044:43933001733884 0:0 hcCommandMarker:91
|
||||
43933017641348:43933019466951 0:0 hcCommandKernel:94
|
||||
43933019470002:43933019501362 0:0 hcCommandMarker:96
|
||||
43933035461722:43933037295325 0:0 hcCommandKernel:99
|
||||
43933037298331:43933037330011 0:0 hcCommandMarker:101
|
||||
43933053199946:43933055040429 0:0 hcCommandKernel:104
|
||||
43933055043394:43933055075234 0:0 hcCommandMarker:106
|
||||
43933071041680:43933072880403 0:0 hcCommandKernel:109
|
||||
43933072883281:43933072915281 0:0 hcCommandMarker:111
|
||||
43933088820348:43933090670751 0:0 hcCommandKernel:114
|
||||
43933090673779:43933090705459 0:0 hcCommandMarker:116
|
||||
3802699751533941:3802699751541991 1983:1983 hipGetDeviceProperties(props=, device=0)
|
||||
3802699752571489:3802699752686289 1983:1983 hipMalloc(ptr=0x7f6c121ff010, size=4194304)
|
||||
3802699752688639:3802699752749390 1983:1983 hipMalloc(ptr=0x7fffefcadf28, size=4194304)
|
||||
3802699752763840:3802700027958750 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700027966800:3802700027966801 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700028567724:3802700028567725 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700041950374:3802700041950375 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700041963674:3802700041963675 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700054151914:3802700054151915 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700054162714:3802700054162715 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700066165433:3802700066165434 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700066176343:3802700066176344 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700078181322:3802700078181323 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700078192012:3802700078192013 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700090220561:3802700090220562 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700090239211:3802700090239212 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700102271721:3802700102271722 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700102282171:3802700102282172 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700114144958:3802700114144959 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700114162049:3802700114162050 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700126128128:3802700126128129 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700126138758:3802700126138759 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700138129156:3802700138129157 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700138139446:3802700138139447 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700150136865:3802700150136866 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700150148016:3802700150148017 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700162246915:3802700162246916 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700162258105:3802700162258106 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700174131823:3802700174131824 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700174149233:3802700174149234 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700186413294:3802700186413295 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700186424475:3802700186424476 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700198692895:3802700198692896 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700198703415:3802700198703416 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700210532173:3802700210532174 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700210542783:3802700210542784 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700222880184:3802700222880185 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700222891274:3802700222891275 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700234962094:3802700234962095 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700234972984:3802700234972985 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700247111934:3802700247111935 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700247122294:3802700247122295 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700259114883:3802700259114884 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700259131593:3802700259131594 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700270919381:3802700270919382 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700270930441:3802700270930442 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700282944209:3802700282944210 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700282954850:3802700282954851 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700294960369:3802700294960370 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700294970439:3802700294970440 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700306951068:3802700306951069 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700306963188:3802700306963189 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700318935636:3802700318935637 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700318952436:3802700318952437 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700330939575:3802700330939576 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700330957096:3802700330957097 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700342957675:3802700342957676 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700342976555:3802700342976556 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700354958353:3802700354958354 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700354969733:3802700354969734 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700367116224:3802700367116225 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700367127874:3802700367127875 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700378910551:3802700378910552 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700378921781:3802700378921782 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700391300403:3802700391300404 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700391311253:3802700391311254 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700403119421:3802700403119422 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700403149901:3802700403149902 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700414928588:3802700414928589 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700414939088:3802700414939089 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700426957197:3802700426957198 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700426969607:3802700426969608 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700438945256:3802700438945257 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700438956156:3802700438956157 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700450955785:3802700450955786 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700450966535:3802700450966536 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700462947734:3802700462947735 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700462958494:3802700462958495 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700475120764:3802700475120765 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700475133244:3802700475133245 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700486943952:3802700486943953 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700486963842:3802700486963843 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700498936501:3802700498936502 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700498947611:3802700498947612 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700510957970:3802700510957971 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700510969340:3802700510969341 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700522956379:3802700522956380 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700522968409:3802700522968410 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700534942538:3802700534942539 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700534953908:3802700534953909 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700546789315:3802700546789316 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700546806236:3802700546806237 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700558559853:3802700558559854 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700558571313:3802700558571314 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700570153708:3802700570153709 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700570176129:3802700570176130 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700581726404:3802700581726405 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700581741565:3802700581741566 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700593057879:3802700593057880 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700593070449:3802700593070450 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700604400132:3802700604400133 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700604413112:3802700604413113 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700615730637:3802700615730638 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700615743157:3802700615743158 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700627079061:3802700627079062 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700627101981:3802700627101982 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700638410875:3802700638410876 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700638425755:3802700638425756 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700649752129:3802700649752130 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700649766079:3802700649766080 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700661088702:3802700661088703 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700661101353:3802700661101354 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700672436427:3802700672436428 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700672449997:3802700672449998 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700683973653:3802700683973654 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700683987193:3802700683987194 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700695366597:3802700695366598 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700695379007:3802700695379008 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700706708861:3802700706708862 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700706735151:3802700706735152 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700718019795:3802700718019796 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700718034725:3802700718034726 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700729346979:3802700729346980 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700729360039:3802700729360040 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700740688063:3802700740688064 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700740702553:3802700740702554 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700752045097:3802700752045098 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700752060217:3802700752060218 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700763470772:3802700763470773 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700763485762:3802700763485763 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700774801006:3802700774801007 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700774813776:3802700774813777 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700786122470:3802700786122471 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700786147830:3802700786147831 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700797490594:3802700797490595 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700797504834:3802700797504835 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700808806748:3802700808806749 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700808822388:3802700808822389 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700820150282:3802700820150283 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700820163482:3802700820163483 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700831687737:3802700831687738 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700831701867:3802700831701868 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700843073042:3802700843073043 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700843096032:3802700843096033 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700854417226:3802700854417227 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700854429236:3802700854429237 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700865753490:3802700865753491 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700865775180:3802700865775181 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700877105074:3802700877105075 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700877120554:3802700877120555 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700888576349:3802700888576350 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700888589579:3802700888589580 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700900086965:3802700900086966 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700900101025:3802700900101026 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700911461388:3802700911461389 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700911474589:3802700911474590 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700922810673:3802700922810674 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700922833153:3802700922833154 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700932447414:3802700934135107 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700934139057:3802700934139058 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700934143817:3802700934144527 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700934146607:3802700934147267 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e03f3099)
|
||||
3802700934158787:3802700934164967 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700934191267:3802700934191268 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700934192847:3802700936775947 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802700943795998:3802700945501111 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700945513191:3802700945513192 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700945517031:3802700945517901 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700945519841:3802700945520521 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e0ecbb86)
|
||||
3802700945522671:3802700945530171 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700945531971:3802700945531972 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700945534701:3802700948131020 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802700955136442:3802700956839355 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700956843375:3802700956843376 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700956847725:3802700956848495 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700956850235:3802700956850825 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e1999f61)
|
||||
3802700956860545:3802700956868795 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700956870695:3802700956870696 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700956872065:3802700959479235 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802700966505397:3802700968203670 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700968207780:3802700968207781 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700968219030:3802700968219770 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700968221700:3802700968222280 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e247222e)
|
||||
3802700968225090:3802700968233560 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700968235360:3802700968235361 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700968241120:3802700970853059 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802700977859821:3802700979559833 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700979563253:3802700979563254 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700979567803:3802700979568553 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700979570433:3802700979571073 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e2f44d18)
|
||||
3802700979581243:3802700979589274 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700979590674:3802700979590675 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700979592044:3802700982222943 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802700989239045:3802700990944838 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802700990948338:3802700990948339 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802700990960008:3802700990960828 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802700990963068:3802700990963638 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e3a221d9)
|
||||
3802700990966328:3802700990975628 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802700990977238:3802700990977239 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700990978718:3802700993694078 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802701000919212:3802701002625515 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802701002628745:3802701002628746 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701002633405:3802701002634215 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802701002635935:3802701002636515 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e45440c4)
|
||||
3802701002649885:3802701002657855 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802701002659335:3802701002659336 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701002660835:3802701005267024 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802701012322026:3802701014008789 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802701014011999:3802701014012000 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701014023469:3802701014024239 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802701014028089:3802701014028669 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e5020cc5)
|
||||
3802701014031569:3802701014039849 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802701014041409:3802701014041410 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701014042919:3802701016640288 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802701023688501:3802701025398903 1983:1983 hipMemcpy(dst=0x7f6c11400000, src=0x7f6c121ff010, sizeBytes=4194304, kind=1)
|
||||
3802701025402873:3802701025402874 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701025407454:3802701025408214 1983:1983 __hipPushCallConfiguration(gridDim=, blockDim=, sharedMem=0, stream=0)
|
||||
3802701025410224:3802701025411104 1983:1983 __hipPopCallConfiguration(gridDim=, blockDim=, sharedMem=140106682958042, stream=0xd8282e5afc125)
|
||||
3802701025412944:3802701025420534 1983:1983 hipLaunchKernel(function_address=0x401030, numBlocks=, dimBlocks=, args=0x3b9aca00, sharedMemBytes=0, stream=0) kernel=matrixTranspose(float*, float*, int)
|
||||
3802701025429704:3802701025429705 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701025431374:3802701028050563 1983:1983 hipMemcpy(dst=0x7f6c11dfe010, src=0x7f6c10e00000, sizeBytes=4194304, kind=2)
|
||||
3802701036808678:3802701036808679 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701036822078:3802701036822079 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701048170132:3802701048170133 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701048184912:3802701048184913 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701059593377:3802701059593378 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701059607287:3802701059607288 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701070985111:3802701070985112 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701071008911:3802701071008912 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701082354665:3802701082354666 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701082369396:3802701082369397 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701093751910:3802701093751911 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701093766810:3802701093766811 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701105308045:3802701105308046 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701105323296:3802701105323297 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701116675540:3802701116675541 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701116689570:3802701116689571 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701128156035:3802701128156036 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701128181736:3802701128181737 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701139551739:3802701139551740 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701139565579:3802701139565580 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701150939144:3802701150939145 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701150961354:3802701150961355 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701162295078:3802701162295079 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701162308528:3802701162308529 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701173678182:3802701173678183 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701173692162:3802701173692163 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802701185053367:3802701185053368 1983:1983 MARK(name(before HIP LaunchKernel))
|
||||
3802701185066667:3802701185066668 1983:1983 MARK(name(after HIP LaunchKernel))
|
||||
3802700025923715:3802700027953920 0:0 CopyHostToDevice:4:1983
|
||||
3802700932468645:3802700934131397 0:0 CopyHostToDevice:159:1983
|
||||
3802700934227596:3802700935424394 0:0 KernelExecution:163:1983
|
||||
3802700934202858:3802700936764597 0:0 CopyDeviceToHost:165:1983
|
||||
3802700943841248:3802700945497221 0:0 CopyHostToDevice:166:1983
|
||||
3802700945593801:3802700946786154 0:0 KernelExecution:170:1983
|
||||
3802700945569841:3802700948120440 0:0 CopyDeviceToHost:172:1983
|
||||
3802700955175473:3802700956835555 0:0 CopyHostToDevice:173:1983
|
||||
3802700956931540:3802700958130412 0:0 KernelExecution:177:1983
|
||||
3802700956907066:3802700959467615 0:0 CopyDeviceToHost:179:1983
|
||||
3802700966543517:3802700968200020 0:0 CopyHostToDevice:180:1983
|
||||
3802700968296336:3802700969501283 0:0 KernelExecution:184:1983
|
||||
3802700968270720:3802700970841439 0:0 CopyDeviceToHost:186:1983
|
||||
3802700977897221:3802700979556403 0:0 CopyHostToDevice:187:1983
|
||||
3802700979653155:3802700980864472 0:0 KernelExecution:191:1983
|
||||
3802700979628944:3802700982210583 0:0 CopyDeviceToHost:193:1983
|
||||
3802700989276246:3802700990941188 0:0 CopyHostToDevice:194:1983
|
||||
3802700991037310:3802700992234553 0:0 KernelExecution:198:1983
|
||||
3802700991012848:3802700993682128 0:0 CopyDeviceToHost:200:1983
|
||||
3802701000959152:3802701002622075 0:0 CopyHostToDevice:201:1983
|
||||
3802701002717521:3802701003911060 0:0 KernelExecution:205:1983
|
||||
3802701002693645:3802701005254464 0:0 CopyDeviceToHost:207:1983
|
||||
3802701012346926:3802701014005359 0:0 CopyHostToDevice:208:1983
|
||||
3802701014102693:3802701015297862 0:0 KernelExecution:212:1983
|
||||
3802701014077439:3802701016629358 0:0 CopyDeviceToHost:214:1983
|
||||
3802701023726221:3802701025394963 0:0 CopyHostToDevice:215:1983
|
||||
3802701025491525:3802701026698101 0:0 KernelExecution:219:1983
|
||||
3802701025467214:3802701028039843 0:0 CopyDeviceToHost:221:1983
|
||||
|
||||
+9336
-3899
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
+9289
-8764
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
Разница между файлами не показана из-за своего большого размера
Загрузить разницу
@@ -1,11 +1,12 @@
|
||||
# dummy
|
||||
MatrixTranspose_ctest_trace --check-diff
|
||||
MatrixTranspose_ctest_trace --check-count .*
|
||||
MatrixTranspose_test_trace --check-count .* --ignore-count hsaKmt.*
|
||||
MatrixTranspose_hipaact_test_trace --check-count .* --ignore-count hsaKmt.*|hipMemcpy|__hipPushCallConfiguration|hipLaunchKernel|__hipPopCallConfiguration
|
||||
MatrixTranspose_mgpu_trace --check-count .* --ignore-count hsaKmt.*
|
||||
MatrixTranspose_sys_trace --check-count .* --ignore-count hsa_.*
|
||||
MatrixTranspose_sys_hsa_trace --check-count .* --ignore-count hsa_.*
|
||||
MatrixTranspose_hip_period_trace --check-events .* --ignore-event hipMalloc|hipFree
|
||||
MatrixTranspose_hip_flush_trace --check-order .*
|
||||
MatrixTranspose_kfd_trace --check-events .*
|
||||
ctrl_hsa_trace --check-count .*
|
||||
ctrl_hsa_input_trace --check-count .*
|
||||
ctrl_hsa_trace --check-event .*
|
||||
ctrl_hsa_input_trace --check-event .*
|
||||
|
||||
@@ -46,17 +46,15 @@ if [ -z "$ROCTRACER_TOOL_PATH" ] ; then
|
||||
ROCTRACER_TOOL_PATH="./test"
|
||||
fi
|
||||
|
||||
env
|
||||
ls -lad /opt/*
|
||||
ls -lad /opt/rocm/*
|
||||
ls -lad /opt/rocm/roctracer/*
|
||||
ls -lad /opt/rocm/roctracer/*/*
|
||||
ls -lad /opt/rocm/roctracer/*/*/*
|
||||
|
||||
# test filter input
|
||||
test_filter=-1
|
||||
check_trace_flag=1
|
||||
if [ -n "$1" ] ; then
|
||||
test_filter=$1
|
||||
shift
|
||||
fi
|
||||
if [ "$2" = "-n" ] ; then
|
||||
check_trace_flag=0
|
||||
fi
|
||||
|
||||
# test check routin
|
||||
@@ -86,8 +84,11 @@ eval_test() {
|
||||
is_failed=0;
|
||||
else
|
||||
if [ $is_failed = 0 ] ; then
|
||||
python ./test/check_trace.py -in $test_name
|
||||
python ./test/check_trace.py -in $test_name -ck $check_trace_flag
|
||||
is_failed=$?
|
||||
if [ $is_failed != 0 ] ; then
|
||||
python ./test/check_trace.py -v -in $test_name -ck $check_trace_flag
|
||||
fi
|
||||
fi
|
||||
fi
|
||||
if [ $is_failed = 0 ] ; then
|
||||
|
||||
Ссылка в новой задаче
Block a user